<?php
/**
 * @package Dashboard Clock
 * @version 1.0
 */
/*
Plugin Name: Dashboard Clock
Plugin URI: https://wordpress.org/plugins/dashboard-clock
Description: A custom colored modern & stylish analog clock for your WordPress dashboard
Version: 1.0
Author: Wahidul Islam Riyad
Author URI: https://profiles.wordpress.org/wahidulislamriyad
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

add_action( 'wp_dashboard_setup', 'dashboard_add_clock_widgets_dc' );
function dashboard_add_clock_widgets_dc() {
	wp_add_dashboard_widget( 'dc_dashboard_clock', 'Dashboard Clock', 'dc_dashboard_clock_handler', 'dc_dashboard_clock_color_hex_config' );
}

function dc_restrictly_get_current_user_role() {
  if( is_user_logged_in() ) {
    $user = wp_get_current_user();
    $role = ( array ) $user->roles;
    return $role[0];
  } else {
    return false;
  }
}

function dc_dashboard_clock_handler() {
	$screen = get_current_screen();
	if ( 'dashboard' === $screen->id && dc_restrictly_get_current_user_role() != false ) {
		$options = wp_parse_args( get_option( 'dc_dashboard_clock' ), dc_dashboard_clock_config_defaults() );
		$color = $options['clock_color'];
		$clock = '<div class="clock_body">
		<br><br>
		<div class="clock" style="background: ' .$color. ' ;">
  			<div class="labels-h"></div>
  			<div class="labels-v"></div>
			<div class="labels-h2"></div>
  			<div class="labels-v2"></div>
			<div class="labels-h3"></div>
  			<div class="labels-v3"></div>
  			<div class="hours"></div>
  			<div class="minutes"></div>
  			<div class="seconds"></div>
		</div>
	<br><br>
	</div>';
	echo wp_kses_post($clock);
	}
}

function dc_dashboard_clock_config_defaults() {
	return array(
		'clock_color' => "#fff",  // Default color for the clock
	);
}

function dc_dashboard_clock_color_hex_config() {
	$screen = get_current_screen();
	if ( 'dashboard' === $screen->id && dc_restrictly_get_current_user_role() != false ) {
		$options = wp_parse_args( get_option( 'dc_dashboard_clock' ), dc_dashboard_clock_config_defaults() );

		if ( isset( $_POST['submit'] ) && isset( $_POST['clock_color'] ) && isset( $_POST['dc_dashboard_clock_color_hex_config_verifier'] ) && wp_verify_nonce( $_POST['dc_dashboard_clock_color_hex_config_verifier'], 'dc_dashboard_clock_color_hex_verifier' ) && sanitize_hex_color( $_POST['clock_color'] ) != '' ) {
			$options['clock_color'] = sanitize_hex_color( $_POST['clock_color'] );
			update_option( 'dc_dashboard_clock', $options );
		}
		if ( isset( $_POST['dc_dashboard_clock_color_hex_config_verifier'] ) && !wp_verify_nonce( $_POST['dc_dashboard_clock_color_hex_config_verifier'], 'dc_dashboard_clock_color_hex_verifier' ) ) {
			header("HTTP/1.0 404 Not Found");
			exit;
		}

    ?>
	<p>
		<label>Clock color
			<input type="color" name="clock_color" value="<?php echo esc_attr( $options['clock_color'] ); ?>">
			<?php wp_nonce_field( 'dc_dashboard_clock_color_hex_verifier', 'dc_dashboard_clock_color_hex_config_verifier' ); ?>
		</label>
	</p>
	<?php
	}
}

add_action( 'admin_enqueue_scripts', 'dc_dashboard_clock_scripts_and_stylesheets' );
function dc_dashboard_clock_scripts_and_stylesheets( $hook ) {
	$screen = get_current_screen();
	if ( 'dashboard' === $screen->id && dc_restrictly_get_current_user_role() != false) {
		wp_enqueue_script( 'dc_dashboard_clock_script', plugin_dir_url(__FILE__) . 'assets/js/script.js', array( 'jquery' ), '1.0', false );
		wp_enqueue_style( 'dc_dashboard_clock_style', plugin_dir_url(__FILE__) . 'assets/css/style.css', array(), '1.0' );   // Stylesheet for the clock
	}
}